/***********************************************************************************************************************************
Restore Command
***********************************************************************************************************************************/
#ifndef COMMAND_RESTORE_RESTORE_H
#define COMMAND_RESTORE_RESTORE_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Restore a backup
FN_EXTERN void cmdRestore(void);

#endif
